# tsjPython

https://pypi.org/project/tsjPython

## use

```python
from tsjPython.tsjCommonFunc import *
passPrint(a)

from tsjPython import tsjCommonFunc
tsjCommonFunc.passPrint(OSACAError)
```

### Install

```python
pip install tsjPython
pip install --upgrade tsjPython
```

## reference

https://www.cnblogs.com/weisunblog/p/13307174.html
